- djm@cvs.openbsd.org 2013/02/18 22:26:47
     [integrity.sh]
     crank the offset yet again; it was still fuzzing KEX one of Darren's
     portable test hosts at 2800
diff --git a/regress/integrity.sh b/regress/integrity.sh
index 4d104c1..261e9f9 100644
--- a/regress/integrity.sh
+++ b/regress/integrity.sh
@@ -1,13 +1,13 @@
-#	$OpenBSD: integrity.sh,v 1.4 2013/02/17 23:16:55 djm Exp $
+#	$OpenBSD: integrity.sh,v 1.5 2013/02/18 22:26:47 djm Exp $
 #	Placed in the Public Domain.
 
 tid="integrity"
 
 # start at byte 2800 (i.e. after kex) and corrupt at different offsets
 # XXX the test hangs if we modify the low bytes of the packet length
 # XXX and ssh tries to read...
 tries=10
-startoffset=2800
+startoffset=2900
 macs="hmac-sha1 hmac-md5 umac-64@openssh.com umac-128@openssh.com
 	hmac-sha1-96 hmac-md5-96 hmac-sha2-256 hmac-sha2-512
 	hmac-sha1-etm@openssh.com hmac-md5-etm@openssh.com
@@ -1,13 +1,13 @@
 tid="integrity"
 
-# start at byte 2800 (i.e. after kex) and corrupt at different offsets
+# start at byte 2900 (i.e. after kex) and corrupt at different offsets
 # XXX the test hangs if we modify the low bytes of the packet length
 # XXX and ssh tries to read...